Merge
authorjwilhelm
Mon, 13 Mar 2017 15:56:09 -0700
changeset 44338 92f2d268e81b
parent 44158 49deb8a1ed3f (current diff)
parent 44337 9e4eb1b70d5b (diff)
child 44339 fb097b1398d9
Merge
--- a/jdk/test/sun/tools/jinfo/JInfoTest.java	Fri Mar 10 21:04:15 2017 -0800
+++ b/jdk/test/sun/tools/jinfo/JInfoTest.java	Mon Mar 13 15:56:09 2017 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005, 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2005, 2017, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -88,8 +88,8 @@
             LingeredApp.startApp(params, app2);
             OutputAnalyzer output = jinfo("JInfoTestLingeredApp");
             output.shouldHaveExitValue(0);
-            // "HotSpot(TM)" written once per proc
-            documentMatch(output.getStdout(), ".*HotSpot\\(TM\\).*HotSpot\\(TM\\).*");
+            // "Runtime Environment" written once per proc
+            documentMatch(output.getStdout(), ".*Runtime Environment.*Runtime Environment.*");
         } finally {
             JInfoTestLingeredApp.stopApp(app1);
             JInfoTestLingeredApp.stopApp(app2);